summaryrefslogtreecommitdiff
path: root/sw/source/filter/ww8/ww8atr.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/filter/ww8/ww8atr.cxx')
-rw-r--r--sw/source/filter/ww8/ww8atr.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sw/source/filter/ww8/ww8atr.cxx b/sw/source/filter/ww8/ww8atr.cxx
index 70e0fe9ba3d1..8094d9d27e3f 100644
--- a/sw/source/filter/ww8/ww8atr.cxx
+++ b/sw/source/filter/ww8/ww8atr.cxx
@@ -1507,10 +1507,10 @@ void WW8AttributeOutput::CharRotate( const SvxCharRotateItem& rRotate )
if ( m_rWW8Export.bWrtWW8 && !m_rWW8Export.IsInTable() )
{
// #i36867 In word the text in a table is rotated via the TC or NS_sprm::LN_TTextFlow
// This means you can only rotate all or none of the text adding NS_sprm::LN_CEastAsianLayout
// here corrupts the table, hence !m_rWW8Export.bIsInTable
- m_rWW8Export.InsUInt16( NS_sprm::LN_CEastAsianLayout );
+ m_rWW8Export.InsUInt16( NS_sprm::LN_CFELayout );
m_rWW8Export.pO->push_back( (sal_uInt8)0x06 ); //len 6
m_rWW8Export.pO->push_back( (sal_uInt8)0x01 );
@@ -3351,7 +3351,7 @@ void WW8AttributeOutput::CharTwoLines( const SvxTwoLinesItem& rTwoLines )
if( !m_rWW8Export.bWrtWW8 )
return;
- m_rWW8Export.InsUInt16( NS_sprm::LN_CEastAsianLayout );
+ m_rWW8Export.InsUInt16( NS_sprm::LN_CFELayout );
m_rWW8Export.pO->push_back( (sal_uInt8)0x06 ); //len 6
m_rWW8Export.pO->push_back( (sal_uInt8)0x02 );
@@ -1507,10 +1507,10 @@ void WW8AttributeOutput::CharRotate( const SvxCharRotateItem& rRotate )
{
// #i36867 In word the text in a table is rotated via the TC or NS_sprm::LN_TTextFlow
- // This means you can only rotate all or none of the text adding NS_sprm::LN_CEastAsianLayout
+ // This means you can only rotate all or none of the text adding NS_sprm::LN_CFELayout
// here corrupts the table, hence !m_rWW8Export.bIsInTable